diff libpurple/upnp.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 56a2a0bb290a
children 1a12ce76c4f4
line wrap: on
line diff
--- a/libpurple/upnp.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/upnp.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file upnp.h Universal Plug N Play API
  * @ingroup core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -23,8 +23,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _GAIM_UPNP_H_
-#define _GAIM_UPNP_H_
+#ifndef _PURPLE_UPNP_H_
+#define _PURPLE_UPNP_H_
 
 typedef struct _UPnPMappingAddRemove UPnPMappingAddRemove;
 
@@ -37,9 +37,9 @@
 /**************************************************************************/
 /*@{*/
 
-/* typedef struct _GaimUPnPRequestData GaimUPnPRequestData; */
+/* typedef struct _PurpleUPnPRequestData PurpleUPnPRequestData; */
 
-typedef void (*GaimUPnPCallback) (gboolean success, gpointer data);
+typedef void (*PurpleUPnPCallback) (gboolean success, gpointer data);
 
 /**
  * Sends a discovery request to search for a UPnP enabled IGD that
@@ -51,17 +51,17 @@
  *           discovery is complete
  * @param cb_data Extra data to be passed to the callback
  */
-void gaim_upnp_discover(GaimUPnPCallback cb, gpointer cb_data);
+void purple_upnp_discover(PurpleUPnPCallback cb, gpointer cb_data);
 
 #if 0
 /**
  * Retrieve the current UPnP control info, if there is any available.
  * This will only be filled in if gaim_upnp_discover() had been called,
  * and finished discovering.
  *
  * @return The control URL for the IGD we'll use to use the IGD services
  */
-const GaimUPnPControlInfo* gaim_upnp_get_control_info(void);
+const PurpleUPnPControlInfo* purple_upnp_get_control_info(void);
 #endif
 
 /**
@@ -72,19 +72,19 @@
  *
  * @return The IP address of the network, or NULL if something went wrong
  */
-const gchar* gaim_upnp_get_public_ip(void);
+const gchar* purple_upnp_get_public_ip(void);
 
 /**
  * Cancel a pending port mapping request initiated with either
- * gaim_upnp_set_port_mapping() or gaim_upnp_remove_port_mapping().
+ * purple_upnp_set_port_mapping() or purple_upnp_remove_port_mapping().
  *
  * @param mapping_data The data returned when you initiated the UPnP mapping request.
  */
-void gaim_upnp_cancel_port_mapping(UPnPMappingAddRemove *mapping_data);
+void purple_upnp_cancel_port_mapping(UPnPMappingAddRemove *mapping_data);
 
 /**
  * Maps Ports in a UPnP enabled IGD that sits on the local network to
  * this gaim client. Essentially, this function takes care of the port
  * forwarding so things like file transfers can work behind NAT firewalls
  *
  * @param portmap The port to map to this client
@@ -93,14 +93,14 @@
  *           addition is complete
  * @param cb_data Extra data to be passed to the callback
  *
  * @return Data which can be passed to gaim_upnp_port_mapping_cancel() to cancel
  */
-UPnPMappingAddRemove *gaim_upnp_set_port_mapping(unsigned short portmap, const gchar* protocol,
-		GaimUPnPCallback cb, gpointer cb_data);
+UPnPMappingAddRemove *purple_upnp_set_port_mapping(unsigned short portmap, const gchar* protocol,
+		PurpleUPnPCallback cb, gpointer cb_data);
 
 /**
  * Deletes a port mapping in a UPnP enabled IGD that sits on the local network
  * to this gaim client. Essentially, this function takes care of deleting the
  * port forwarding after they have completed a connection so another client on
  * the local network can take advantage of the port forwarding
  *
@@ -110,10 +110,10 @@
  *           removal is complete
  * @param cb_data Extra data to be passed to the callback
  *
  * @return Data which can be passed to gaim_upnp_port_mapping_cancel() to cancel
  */
-UPnPMappingAddRemove *gaim_upnp_remove_port_mapping(unsigned short portmap,
-		const gchar* protocol, GaimUPnPCallback cb, gpointer cb_data);
+UPnPMappingAddRemove *purple_upnp_remove_port_mapping(unsigned short portmap,
+		const gchar* protocol, PurpleUPnPCallback cb, gpointer cb_data);
 
 /*@}*/
 
@@ -121,4 +121,4 @@
 }
 #endif
 
-#endif /* _GAIM_UPNP_H_ */
+#endif /* _PURPLE_UPNP_H_ */
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -51,17 +51,17 @@
 /**
  * Retrieve the current UPnP control info, if there is any available.
- * This will only be filled in if gaim_upnp_discover() had been called,
+ * This will only be filled in if purple_upnp_discover() had been called,
  * and finished discovering.
  *
@@ -72,19 +72,19 @@
 /**
  * Maps Ports in a UPnP enabled IGD that sits on the local network to
- * this gaim client. Essentially, this function takes care of the port
+ * this purple client. Essentially, this function takes care of the port
  * forwarding so things like file transfers can work behind NAT firewalls
  *
@@ -93,14 +93,14 @@
  * @param cb_data Extra data to be passed to the callback
  *
- * @return Data which can be passed to gaim_upnp_port_mapping_cancel() to cancel
+ * @return Data which can be passed to purple_upnp_port_mapping_cancel() to cancel
  */
@@ -93,14 +93,14 @@
 /**
  * Deletes a port mapping in a UPnP enabled IGD that sits on the local network
- * to this gaim client. Essentially, this function takes care of deleting the
+ * to this purple client. Essentially, this function takes care of deleting the
  * port forwarding after they have completed a connection so another client on
  * the local network can take advantage of the port forwarding
@@ -110,10 +110,10 @@
  * @param cb_data Extra data to be passed to the callback
  *
- * @return Data which can be passed to gaim_upnp_port_mapping_cancel() to cancel
+ * @return Data which can be passed to purple_upnp_port_mapping_cancel() to cancel
  */